onEngineUpdate property

bool Function() onEngineUpdate
final

Recomputes the owner and reports whether the value changed (equals -filtered) — the engine's propagation-cut hook.

Recomputa o dono e reporta se o valor mudou (filtrado por equals) — o gancho de corte de propagação do motor.

Implementation

final bool Function() onEngineUpdate;