onDependencyChanged property
Invoked when any observable read during this context later changes.
Invocado quando qualquer observável lido durante este contexto mudar posteriormente.
Implementation
final ObserverVoidCallback onDependencyChanged;
Invoked when any observable read during this context later changes.
Invocado quando qualquer observável lido durante este contexto mudar posteriormente.
final ObserverVoidCallback onDependencyChanged;