WatcherNode class final

Effect-like node bridging engine invalidation to external listener notification for a CoreComputed that currently has listeners.

Nó tipo effect fazendo a ponte entre a invalidação do motor e a notificação de listeners externos para um CoreComputed que atualmente tem listeners.

Inheritance

Constructors

WatcherNode({required void onInvalidate()})
Creates a watcher that calls onInvalidate when its dependency (the owning computed's node) may have changed.

Properties

deps ReactiveLink?
Head of this node's dependency list. / Cabeça da lista de dependências.
getter/setter pairinherited
depsTail ReactiveLink?
Tail of the dependency list (O(1) append; also the re-tracking cursor — see ReactiveEngine.link). / Cauda da lista de dependências (append O(1); também o cursor de re-rastreamento — ver ReactiveEngine.link).
getter/setter pairinherited
flags ReactiveFlags
Current state flags. / Flags de estado atuais.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
onInvalidate → void Function()
Owner-provided scheduling callback (queues a pull in the current batch/flush).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subs ReactiveLink?
Head of this node's subscriber list. / Cabeça da lista de subscribers.
getter/setter pairinherited
subsTail ReactiveLink?
Tail of the subscriber list. / Cauda da lista de subscribers.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited