ObservableCreateEvent class
Emitted when an Observable/Computed is created.
Emitido quando um Observable/Computed é criado.
- Inheritance
-
- Object
- ObservableEvent
- ObservableCreateEvent
Constructors
- ObservableCreateEvent(String label, Object? initialValue, {StackTrace? stackTrace})
-
Creates a create-event for
labelholdinginitialValue.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialValue → Object?
-
The value the observable was created with.
final
- label → String
-
Debug label of the observable/Computed/Effect/Observer this event is
about.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
Stack trace captured at the point of the event, if
ObserverConfig.captureStackTraceswas enabled.nullotherwise (the default, since capturing a trace on every event is not free).finalinherited - timestamp → DateTime
-
When this event occurred.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited