ObservableDisposeEvent class
Emitted when an Observable/Computed is disposed.
Emitido quando um Observable/Computed é descartado.
- Inheritance
-
- Object
- ObservableEvent
- ObservableDisposeEvent
Constructors
- ObservableDisposeEvent(String label, int listenerCount, {StackTrace? stackTrace})
-
Creates a dispose-event for
label, noting how manylistenerCountlisteners were removed.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
Debug label of the observable/Computed/Effect/Observer this event is
about.
finalinherited
- listenerCount → int
-
Number of listeners that were attached at the moment of disposal.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
Stack trace captured at the point of the event, if
ObserverConfig.captureStackTraceswas enabled.nullotherwise (the default, since capturing a trace on every event is not free).finalinherited - timestamp → DateTime
-
When this event occurred.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited