stackTrace property
Stack trace captured at the point of the event, if
ObserverConfig.captureStackTraces was enabled. null otherwise
(the default, since capturing a trace on every event is not free).
Stack trace capturado no ponto do evento, se
ObserverConfig.captureStackTraces estava habilitado. null caso
contrário (o padrão, já que capturar um trace a cada evento não é
gratuito).
Implementation
final StackTrace? stackTrace;