ObservableUpdateEvent class

Emitted when an Observable/Computed notifies a value change.

Emitido quando um Observable/Computed notifica uma mudança de valor.

Inheritance

Constructors

ObservableUpdateEvent(String label, Object? oldValue, Object? newValue, {StackTrace? stackTrace})
Creates an update-event for label going from oldValue to newValue.

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
Debug label of the observable/Computed/Effect/Observer this event is about.
finalinherited
newValue Object?
The value immediately after this change.
final
oldValue Object?
The value immediately before this change.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
Stack trace captured at the point of the event, if ObserverConfig.captureStackTraces was enabled. null otherwise (the default, since capturing a trace on every event is not free).
finalinherited
timestamp DateTime
When this event occurred.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited