flushEpoch property
int
get
flushEpoch
Monotonic identifier for the currently running batch flush. Intended for internal schedulers that need to distinguish invalidations from the same flush wave from future external writes.
Identificador monotônico do flush de batch em execução. Destinado a schedulers internos que precisam distinguir invalidações do mesmo flush de escritas externas futuras.
Implementation
static int get flushEpoch => _flushEpoch;