trackedLabels property
Debug-only labels of the distinct observables read during this context, in read order. Used for the Observer tracking log.
Rótulos (debug) dos observáveis distintos lidos durante este contexto, na ordem de leitura. Usado no log de rastreamento do Observer.
Implementation
final List<String> trackedLabels = <String>[];