EngineStack<T> class
final
Minimal linked stack used to make ReactiveEngine.propagate and ReactiveEngine.checkDirty iterative instead of recursive, so graph depth is bounded by heap, not by the call stack.
Pilha ligada mínima usada para tornar ReactiveEngine.propagate e ReactiveEngine.checkDirty iterativos em vez de recursivos, de modo que a profundidade do grafo seja limitada pelo heap, não pela call stack.
Constructors
-
EngineStack({required T value, EngineStack<
T> ? prev}) -
Pushes
valueon top ofprev. / Empilhavaluesobreprev.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
prev
→ EngineStack<
T> ? -
The frame below this one, or
nullat the bottom. / O quadro abaixo deste, ounullna base.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
The payload of this frame. / A carga deste quadro.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited